#include <iostream>
#include "TObjArray.h"

#include "rootfilehandler.h"
#include <stdlib.h>
using namespace std;

void
CreateRootFile(
        const char*     loc_fname,
        int             verbosityLevel
        )
{
    TFile* tf = new TFile(loc_fname,"UPDATE");
    if (tf->IsZombie())
    {
        cout << "Error opening file" << endl;
        exit(-1);
    }
    else {
        if (verbosityLevel > 1) cout << "creating root-file successfull" << endl;
        tf->Close();
    }
}
//end of CreateRootFile
//----------------------------------------------------------------------------


void
OpenRootFile(
        TFile*          output_rootfile,
        const char *    loc_fname,
        int             verbosityLevel
        )
{
    output_rootfile = new TFile(loc_fname,"UPDATE");
    if (output_rootfile->IsZombie())
    {
        cout << "Error opening file" << endl;
        exit(-1);
    }
    else
    {
        if (verbosityLevel > 1)
        {
            cout << "...opening root-file:"
                 << loc_fname
                 << " successfull" << endl;
        }
    }
    return;
}
//end of OpenRootFile
//----------------------------------------------------------------------------


void
CloseRootFile(
        TFile* output_rootfile
        )
{
    if (output_rootfile->IsZombie())
    {
    cout << "Error closing file" << endl;
    exit(-1);
    } else {
    output_rootfile->Close();
    delete output_rootfile;
    }
}
//end of CloseRootFile
//----------------------------------------------------------------------------


void
SaveHistograms(
        const char*     loc_fname,
        TString         subdirectory,
        TObjArray*      histList,
        bool            saveResults,
        int             verbosityLevel
        )
{
    if (!saveResults) return;
    if (verbosityLevel > 2) cout << endl
                                 << "...saving pixel histograms to subdirectory: "
                                 << subdirectory << endl ;

    TFile* output_rootfile = NULL;
    OpenRootFile(output_rootfile, loc_fname, verbosityLevel);
    if ( !( subdirectory.CompareTo("root") ) ) //if subdirectory = root
    {
        output_rootfile->cd();
    }
    else
    {
        output_rootfile->cd();
        output_rootfile->mkdir(subdirectory,subdirectory);
        output_rootfile->cd(subdirectory);
    }
    histList->Write(); // write the major histograms into the top level directory
    if (verbosityLevel > 3) tf->ls();
    CloseRootFile( output_rootfile ); // close the file
    if (verbosityLevel > 2) cout << "...done" << endl;
}
// end of SaveHistograms
//----------------------------------------------------------------------------


TString
CreateSubDirName(
        int pixel
        )
{
    TString path = "Pixel_";
    path += pixel;
//    cout << "path " << path << endl ;
    return path;
}
// end of CreateSubDirName
//----------------------------------------------------------------------------


TString
CreateSubDirName(
        const char* title
        )
{
    TString path = title;
    path += "_Pixel";
//    cout << "path " << path << endl ;
    return path;
}
// end of CreateSubDirName
//----------------------------------------------------------------------------

